Reference
=========

.. autosummary::
   :toctree: _autosummary
   :recursive:
   :template: summary-module.rst

   fusionsc

..
  Service interface
  -----------------

  Java
  ~~~~

  .. toctree::
    :glob:
    :maxdepth: 2
  
    javadocs/*.package